translate.lang.fr

Package translate :: Package lang :: Module fr |
[hide private]
[frames] | no frames]

# Module fr

source code

This module represents French language.

For more information, see http://en.wikipedia.org/wiki/French_language

Classes | [hide private]
| fr This class represents French.

Functions | [hide private]
guillemets(text) | source code

Variables | [hide private]
| __package__ = ``'``translate.lang``'``

Imports: re, common